Players class

Total and connected players.

Annotations
  • @freezed

Constructors

Players({required int max, required int online, List<Sample>? sample})
Total and connected players.
const
factory
Players.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PlayersCopyWith<Players>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
max int
Max players.
no setterinherited
online int
Connected players.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sample List<Sample>?
Connected players list.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited