Sample class

A server's player.

Annotations
  • @freezed

Constructors

Sample({required String id, required String name})
A server's player.
const
factory
Sample.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $SampleCopyWith<Sample>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Players' UUID.
no setterinherited
name String
Players' name.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited